@@ -11,7 +11,7 @@ require 'mkmf'
 require 'fileutils'
 require 'pathname'
 
-priorlibs = ["glib", "gdkpixbuf", "pango", "atk", "gtk"]
+priorlibs = ["glib2", "gio2", "gdk_pixbuf2", "pango", "atk", "gtk2"]
 
 #
 # detect sub-directories
@@ -37,7 +37,7 @@ $topdir = File.expand_path($topdir)
 subdirs = ARGV.select{|v|  /^--/ !~ v}
 
 if subdirs.size == 0
-  subdirs = Dir.glob($topsrcdir+"/*/**/extconf.rb")
+  subdirs = Dir.glob($topsrcdir+"/*/extconf.rb")
   subdirs.collect! do |subdir|
     subdir[0..$topsrcdir.size] = ""
     File.dirname(subdir)
@@ -69,7 +69,7 @@ subdirs.each do |subdir|
   srcdir = File.join(dir, subdir)
   args = ruby_args + ["-C", subdir, File.join(srcdir, "extconf.rb"),
                       "--topsrcdir=#{dir}", "--topdir=#{topdir}",
-                      "--srcdir=#{srcdir}", *extra_args]
+                      *extra_args]
   ret = system(ruby, *args)
   STDERR.puts("#{$0}: Leaving directory '#{subdir}'")
   if ret
